:orphan:

Citing Matplotlib
=================

If Matplotlib contributes to a project that leads to a scientific publication,
please acknowledge this fact by citing `J. D. Hunter, "Matplotlib: A 2D
Graphics Environment", Computing in Science & Engineering, vol. 9, no. 3,
pp. 90-95, 2007 <https://doi.org/10.1109/MCSE.2007.55>`_.

.. code-block:: bibtex

   @Article{Hunter:2007,
     Author    = {Hunter, J. D.},
     Title     = {Matplotlib: A 2D graphics environment},
     Journal   = {Computing in Science \& Engineering},
     Volume    = {9},
     Number    = {3},
     Pages     = {90--95},
     abstract  = {Matplotlib is a 2D graphics package used for Python for
     application development, interactive scripting, and publication-quality
     image generation across user interfaces and operating systems.},
     publisher = {IEEE COMPUTER SOC},
     doi       = {10.1109/MCSE.2007.55},
     year      = 2007
   }

DOIs
----

The following DOI represents *all* Matplotlib versions. Please select a more
specific DOI from the list below, referring to the version used for your publication.

   .. image:: https://zenodo.org/badge/DOI/10.5281/zenodo.592536.svg
      :target: https://doi.org/10.5281/zenodo.592536

By version
~~~~~~~~~~
.. START OF AUTOGENERATED


v3.3.1
   .. image:: _static/zenodo_cache/3984190.svg
      :target:  https://doi.org/10.5281/zenodo.3984190
v3.3.0
   .. image:: _static/zenodo_cache/3948793.svg
      :target:  https://doi.org/10.5281/zenodo.3948793
v3.2.2
   .. image:: _static/zenodo_cache/3898017.svg
      :target:  https://doi.org/10.5281/zenodo.3898017
v3.2.1
   .. image:: _static/zenodo_cache/3714460.svg
      :target:  https://doi.org/10.5281/zenodo.3714460
v3.2.0
   .. image:: _static/zenodo_cache/3695547.svg
      :target:  https://doi.org/10.5281/zenodo.3695547
v3.1.3
   .. image:: _static/zenodo_cache/3633844.svg
      :target:  https://doi.org/10.5281/zenodo.3633844
v3.1.2
   .. image:: _static/zenodo_cache/3563226.svg
      :target:  https://doi.org/10.5281/zenodo.3563226
v3.1.1
   .. image:: _static/zenodo_cache/3264781.svg
      :target:  https://doi.org/10.5281/zenodo.3264781
v3.1.0
   .. image:: _static/zenodo_cache/2893252.svg
      :target:  https://doi.org/10.5281/zenodo.2893252
v3.0.3
   .. image:: _static/zenodo_cache/2577644.svg
      :target:  https://doi.org/10.5281/zenodo.2577644
v3.0.2
   .. image:: _static/zenodo_cache/1482099.svg
      :target:  https://doi.org/10.5281/zenodo.1482099
v3.0.1
   .. image:: _static/zenodo_cache/1482098.svg
      :target:  https://doi.org/10.5281/zenodo.1482098
v2.2.5
   .. image:: _static/zenodo_cache/3633833.svg
      :target:  https://doi.org/10.5281/zenodo.3633833
v3.0.0
   .. image:: _static/zenodo_cache/1420605.svg
      :target:  https://doi.org/10.5281/zenodo.1420605
v2.2.4
   .. image:: _static/zenodo_cache/2669103.svg
      :target:  https://doi.org/10.5281/zenodo.2669103
v2.2.3
   .. image:: _static/zenodo_cache/1343133.svg
      :target:  https://doi.org/10.5281/zenodo.1343133
v2.2.2
   .. image:: _static/zenodo_cache/1202077.svg
      :target:  https://doi.org/10.5281/zenodo.1202077
v2.2.1
   .. image:: _static/zenodo_cache/1202050.svg
      :target:  https://doi.org/10.5281/zenodo.1202050
v2.2.0
   .. image:: _static/zenodo_cache/1189358.svg
      :target:  https://doi.org/10.5281/zenodo.1189358
v2.1.2
   .. image:: _static/zenodo_cache/1154287.svg
      :target:  https://doi.org/10.5281/zenodo.1154287
v2.1.1
   .. image:: _static/zenodo_cache/1098480.svg
      :target:  https://doi.org/10.5281/zenodo.1098480
v2.1.0
   .. image:: _static/zenodo_cache/1004650.svg
      :target:  https://doi.org/10.5281/zenodo.1004650
v2.0.2
   .. image:: _static/zenodo_cache/573577.svg
      :target:  https://doi.org/10.5281/zenodo.573577
v2.0.1
   .. image:: _static/zenodo_cache/570311.svg
      :target:  https://doi.org/10.5281/zenodo.570311
v2.0.0
   .. image:: _static/zenodo_cache/248351.svg
      :target:  https://doi.org/10.5281/zenodo.248351
v1.5.3
   .. image:: _static/zenodo_cache/61948.svg
      :target:  https://doi.org/10.5281/zenodo.61948
v1.5.2
   .. image:: _static/zenodo_cache/56926.svg
      :target:  https://doi.org/10.5281/zenodo.56926
v1.5.1
   .. image:: _static/zenodo_cache/44579.svg
      :target:  https://doi.org/10.5281/zenodo.44579
v1.5.0
   .. image:: _static/zenodo_cache/32914.svg
      :target:  https://doi.org/10.5281/zenodo.32914
v1.4.3
   .. image:: _static/zenodo_cache/15423.svg
      :target:  https://doi.org/10.5281/zenodo.15423
v1.4.2
   .. image:: _static/zenodo_cache/12400.svg
      :target:  https://doi.org/10.5281/zenodo.12400
v1.4.1
   .. image:: _static/zenodo_cache/12287.svg
      :target:  https://doi.org/10.5281/zenodo.12287
v1.4.0
   .. image:: _static/zenodo_cache/11451.svg
      :target:  https://doi.org/10.5281/zenodo.11451

.. END OF AUTOGENERATED
